@@ -1,4 +1,11 @@
 
+#ifndef __SERIAL_H_
+#define __SERIAL_H_
+
+#ifdef WIN32
+#define	bool	int
+#endif
+
 bool ByteWaiting(int theDevice,unsigned int timeOut);
 unsigned int ReadBytes(int theDevice,unsigned char *theBytes,unsigned int maxBytes,unsigned int timeOut);
 void WriteBytes(int theDevice,unsigned char *theBytes,unsigned int numBytes);
@@ -10,3 +17,5 @@ void GetDeviceStatus(int theDevice,bool *CTS,bool *DCD);
 void SetDTR(int theDevice,bool DTR);
 bool OpenDevice(char *theName,int *theDevice);
 void CloseDevice(int theDevice);
+
+#endif // defined __SERIAL_H_
